@@ -79,6 +79,7 @@ or start project with authentication and authorization support::
     name = None
     auth = None
     geo = False
+    tw1 = False
     package = None
     svn_repository = None
     sqlalchemy = True
@@ -104,6 +105,14 @@ or start project with authentication and authorization support::
             help="default templates mako",
             action="store_true", dest="mako")
 
+    parser.add_option("-j", "--jinja",
+        help="default templates jinja",
+        action="store_true", dest="jinja")
+
+    parser.add_option("-k", "--kajiki",
+        help="default templates kajiki",
+        action="store_true", dest="kajiki")
+
     parser.add_option("-g", "--geo",
             help="add GIS support",
             action="store_true", dest="geo")
@@ -128,9 +137,9 @@ or start project with authentication and authorization support::
             help="disable sqlalchemy-migrate model migrations",
             action="store_false", dest="migrations", default=True)
 
-    parser.add_option("--minimal",
-            help="use the minimal template to quickstart your application",
-            action="store_true", dest="minimal", default=False)
+    parser.add_option("--enable-tw1",
+        help="use toscawidgets 1.x in place of 2.x version",
+        action="store_true", dest="tw1", default=False)
 
     parser.add_option("--dry-run",
             help="dry run (don't actually do anything)",
@@ -176,19 +185,28 @@ or start project with authentication and authorization support::
                         "Enter package name [%s]: " % package).strip() or package
 
         if self.no_input:
-
             #defaults
             self.mako = False
+            self.jinja = False
+            self.kajiki = False
             self.auth = True
 
-        while self.mako is None:
-            self.mako = raw_input(
-                "Would you prefer mako templates? (yes/[no]): ")
-            self.mako = dict(y=True, n=False).get(
-                self.mako.lstrip()[:1].lower() or 'n')
-            if self.mako is None:
-                print "Please enter y(es) or n(o)."
-
+        if self.jinja is None and self.mako is None and self.kajiki is None:
+            template = None
+            while template is None:
+                template = raw_input(
+                    "Would you prefer to use an alternative template system? (m=mako, j=jinja, k=kajiki, n=no [default]): ")
+		template = dict(m="mako", j="jinja", k='kajiki', n="none").get(
+                    template.lstrip()[:1].lower() or 'n')
+                if template == "mako":
+                    self.mako = True
+                elif template == "jinja":
+                    self.jinja = True
+                elif template == "kajiki":
+                    self.kajiki = True
+                elif template is None:
+                    print "Please enter an option or n(o)."
+                
         while self.auth is None:
             self.auth = raw_input(
                 "Do you need authentication and authorization"
@@ -242,8 +260,6 @@ or start project with authentication and authorization support::
         command = create_distro.CreateDistroCommand("create")
         cmd_args = []
         templates = self.templates.split()
-        if self.minimal:
-            templates = ['turbogears2-minimal']
         for template in templates:
             cmd_args.append("--template=%s" % template)
         if self.dry_run:
@@ -254,9 +270,12 @@ or start project with authentication and authorization support::
         cmd_args.append("ming=%s" % self.ming)
         cmd_args.append("auth=%s" % self.auth)
         cmd_args.append("geo=%s" % self.geo)
+        cmd_args.append("tw1=%s" % self.tw1)
         cmd_args.append("package=%s" % self.package)
         cmd_args.append("tgversion=%s" % self.version)
         cmd_args.append("mako=%s"%self.mako)
+        cmd_args.append("jinja=%s"%self.jinja)
+        cmd_args.append("kajiki=%s"%self.kajiki)
         cmd_args.append("migrations=%s"%self.migrations)
         cmd_args.append("cookiesecret=%s"%self.cookiesecret)
         # set the exact ORM-version for the proper requirements
@@ -281,17 +300,23 @@ or start project with authentication and authorization support::
                 if file == "empty":
                     os.remove(os.path.join(base, file))
 
-        #copy over the mako templates if appropriate
-        if self.mako:
-            print 'Writing mako template files to ./'+os.path.join(self.package, 'templates')
+        #copy over the alternative templates if appropriate
+        if self.mako or self.kajiki or self.jinja:
+            def overwrite_templates(template_type):
+                print 'Writing ' + template_type + ' template files to ./'+os.path.join(self.package, 'templates')
+                #remove existing template files
+                package_template_dir = os.path.abspath(os.path.join(self.package, 'templates'))
+                shutil.rmtree(package_template_dir, ignore_errors=True)
+                #replace template files with alternative ones
+                alt_template_dir = os.path.abspath(os.path.dirname(__file__))+'/quickstart_'+template_type
+                shutil.copytree(alt_template_dir, package_template_dir)
 
-            #remove existing template files
-            package_template_dir = os.path.abspath(os.path.join(self.package, 'templates'))
-            shutil.rmtree(package_template_dir, ignore_errors=True)
-
-            #replace template files with mako ones
-            mako_template_dir = os.path.abspath(os.path.dirname(__file__))+'/quickstart_mako'
-            shutil.copytree(mako_template_dir, package_template_dir)
+            if self.mako:
+                overwrite_templates('mako')
+            elif self.jinja:
+                overwrite_templates('jinja')
+            elif self.kajiki:
+                overwrite_templates('kajiki')
 
         if self.ming:
             print 'Writing Ming model files to ./'+os.path.join(self.package, 'model')
